AppSettings class

Constructors

AppSettings({String? name, dynamic value, String? type})
AppSettings.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

getAllSettings() Stream<List<AppSettings>>
getSettingAsBool(String settingsName) bool
getSettingsAsMap(String settingname) Map<String, dynamic>?
getSettingsAsNumber(String settingname, int defaultvalue) int
getSettingsValueAsString(String settingname) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startSettingsStream() → void
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance List<AppSettings>?
no setter